@@ -12,10 +12,10 @@ my $lc = ' *';
 
 #my $VERSION   = '<VERSION>';
 #my $DATE   = '<DATE>';
-my $VERSION   = '5.2.2';
-my $DATE   = '26.07.2022';
-my $YEAR  = '2022';
-my $AUTHOR = 'NHR@FAU, University Erlangen-Nuremberg';
+my $VERSION   = '5.3';
+my $DATE   = '10.11.2023';
+my $YEAR  = '2023';
+my $AUTHOR = 'RRZE, University Erlangen-Nuremberg';
 my $LICENSE = 'gpl';
 
 my @SKIPLIST = ('ghash.c','ghash.h','loadData.S','loadDataARM.S','bstrlib.c','bstrlib.h', 'calculator_stack.h', 'calculator_stack.c');
