@@ -5,13 +5,13 @@
  *
  *      Description:  Interface to the access daemon for the access module.
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -152,7 +152,7 @@ access_client_startDaemon(int cpu_id)
     if (access(exeprog, X_OK))
     {
         ERROR_PRINT(Failed to find the daemon '%s'\n, exeprog);
-        exit(EXIT_FAILURE);
+        return -1;
     }
     DEBUG_PRINT(DEBUGLEV_INFO, Starting daemon %s, exeprog);
     pid = fork();
@@ -174,7 +174,7 @@ access_client_startDaemon(int cpu_id)
         {
             //ERRNO_PRINT;
             ERROR_PRINT(Failed to execute the daemon '%s'\n, exeprog);
-            exit(EXIT_FAILURE);
+            return ret;
         }
     }
     else if (pid < 0)
@@ -183,12 +183,28 @@ access_client_startDaemon(int cpu_id)
         return pid;
     }
 
-    EXIT_IF_ERROR(socket_fd = socket(AF_LOCAL, SOCK_STREAM, 0), socket() failed);
+    socket_fd = socket(AF_LOCAL, SOCK_STREAM, 0);
+    if (socket_fd < 0)
+    {
+        ERROR_PRINT(socket() failed);
+        return -1;
+    }
 
     address.sun_family = AF_LOCAL;
     address_length = sizeof(address);
     snprintf(address.sun_path, sizeof(address.sun_path), TOSTRING(LIKWIDSOCKETBASE) "-%d", pid);
     filepath = strdup(address.sun_path);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, Waiting for socket file %s, address.sun_path);
+    while (access(address.sun_path, F_OK) && timeout > 0)
+    {
+        usleep(2500);
+        timeout--;
+    }
+    if (!access(address.sun_path, F_OK))
+    {
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, Socket file %s exists, address.sun_path);
+    }
+    timeout = 1000;
 
     res = connect(socket_fd, (struct sockaddr *) &address, address_length);
     while (res && timeout > 0)
@@ -212,7 +228,9 @@ access_client_startDaemon(int cpu_id)
         fprintf(stderr, "opened within 10 seconds. Consult the error message above\n");
         fprintf(stderr, "this to find out why. If the error is 'no such file or directoy',\n");
         fprintf(stderr, "it usually means that likwid-accessD just failed to start.\n");
-        exit(EXIT_FAILURE);
+        free(filepath);
+        close(socket_fd);
+        return -1;
     }
     DEBUG_PRINT(DEBUGLEV_INFO, Successfully opened socket %s to daemon for CPU %d, filepath, cpu_id);
     free(filepath);
@@ -358,12 +376,12 @@ access_client_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t
             if (dev == MSR_DEV)
             {
                 DEBUG_PRINT(DEBUGLEV_DEVELOP, Got error '%s' from access daemon reading reg 0x%X at CPU %d,
-                            access_client_strerror(record.errorcode), reg, cpu_id);
+                            access_client_strerror(record.errorcode), reg, record.cpu);
             }
             else
             {
                 DEBUG_PRINT(DEBUGLEV_DEVELOP, Got error '%s' from access daemon reading reg 0x%X on socket %d,
-                            access_client_strerror(record.errorcode), reg, cpu_id);
+                            access_client_strerror(record.errorcode), reg, record.cpu);
             }
             *data = 0;
             return access_client_errno(record.errorcode);
@@ -448,12 +466,12 @@ access_client_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t
             if (dev == MSR_DEV)
             {
                 DEBUG_PRINT(DEBUGLEV_DEVELOP, Got error '%s' from access daemon writing reg 0x%X at CPU %d,
-                            access_client_strerror(record.errorcode), reg, cpu_id);
+                            access_client_strerror(record.errorcode), reg, record.cpu);
             }
             else
             {
                 DEBUG_PRINT(DEBUGLEV_DEVELOP, Got error '%s' from access daemon writing reg 0x%X on socket %d,
-                            access_client_strerror(record.errorcode), reg, cpu_id);
+                            access_client_strerror(record.errorcode), reg, record.cpu);
             }
             return access_client_errno(record.errorcode);
         }
@@ -534,7 +552,16 @@ access_client_check(PciDeviceIndex dev, int cpu_id)
         }
         else
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Device check for dev %d on CPU %d with accessDaemon failed: %s\n, dev, cpu_id, access_client_strerror(record.errorcode));
+            if (dev == MSR_DEV)
+            {
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, Device check for dev %d on CPU %d with accessDaemon failed,
+                            dev, record.cpu, access_client_strerror(record.errorcode));
+            }
+            else
+            {
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, Device check for dev %d on socket %d with accessDaemon failed,
+                            dev, record.cpu, access_client_strerror(record.errorcode));
+            }
         }
     }
     return 0;
