@@ -5,14 +5,14 @@
  *
  *      Description:  Implementation of affinity module.
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -526,20 +526,28 @@ affinity_init()
     }
     topology_init();
     CpuTopology_t cputopo = get_cpuTopology();
+    CpuInfo_t cpuinfo = get_cpuInfo();
     numa_init();
     NumaTopology_t numatopo = get_numaTopology();
 
+    int doCacheDomains = 1;
     int numberOfCacheDomains = 0;
     int numberOfCoresPerCache = 0;
     int numberOfProcessorsPerCache = 0;
 
+    /* check system and remove domains if needed */
+    if (cpuinfo->vendor == APPLE_M1 && cpuinfo->model == APPLE_M1_STUDIO)
+    {
+        doCacheDomains = 0;
+    }
+
     /* determine total number of domains */
     numberOfDomains = 1;
     numberOfDomains += cputopo->numSockets;
     DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity: Socket domains %d, cputopo->numSockets);
     numberOfDomains += (cputopo->numDies > 0 ? cputopo->numDies : cputopo->numSockets);
     DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity: CPU die domains %d, (cputopo->numDies > 0 ? cputopo->numDies : cputopo->numSockets));
-    if (cputopo->numCacheLevels > 0)
+    if (doCacheDomains && cputopo->numCacheLevels > 0)
     {
         numberOfProcessorsPerCache = cputopo->cacheLevels[cputopo->numCacheLevels-1].threads;
         numberOfCoresPerCache = numberOfProcessorsPerCache / cputopo->numThreadsPerCore;
@@ -602,7 +610,7 @@ affinity_init()
         }
     }
     /* Last level cache domains */
-    if (cputopo->numCacheLevels > 0)
+    if (doCacheDomains && cputopo->numCacheLevels > 0)
     {
         for (int i = 0; i < cputopo->numSockets; i++)
         {
