@@ -7,13 +7,13 @@
  *      Description: A wrapper script to pin threads spawned by MPI processes and
  *                   measure hardware performance counters
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -110,9 +110,10 @@ local hosts = {}
 local perf = {}
 local mpitype = nil
 local slurm_involved = false
+local slurm_no_tasks_per_node = false
 local omptype = nil
 local skipStr = ""
-local executable = {}
+local execList = {}
 local envsettings = {}
 local mpiopts = nil
 local debug = false
@@ -136,9 +137,10 @@ local executeCommand = nil
 local mpiexecutable = nil
 local hostpattern = "([%.%a%d_-]+)"
 local pid = likwid.getpid()
+local pwd = os.getenv("PWD")
 local hostfilename = string.format(".hostfile_%s.txt", pid)
 local scriptfilename = string.format(".likwidscript_%s.txt", pid)
-local outfilename = string.format(os.getenv("PWD").."/.output_%s_%%r_%%h.csv", pid)
+local outfilename = string.format("%s/.output_%s_%%r_%%h.csv", pwd, pid)
 local filelist = {}
 
 local function mpirun_exit(exitcode)
@@ -149,6 +151,7 @@ local function mpirun_exit(exitcode)
             os.remove(file)
         end
     end
+    os.execute(string.format("rm --force %s/.output_%s*", pwd, pid))
     os.exit(exitvalue)
 end
 
@@ -650,9 +653,11 @@ local function executeSlurm(wrapperscript, hostfile, env, nrNodes)
     end
     opts["nodes"] = string.format("%d", nrNodes)
     opts["ntasks"] = string.format("%d", np)
-    opts["ntasks-per-node"] = string.format("%d", ppn)
+    if not slurm_no_tasks_per_node then
+        opts["ntasks-per-node"] = string.format("%d", ppn)
+    end
     opts["cpu_bind"] = "none"
-    opts["cpus-per-task"] = string.format("%d", threads)
+    opts["cpus-per-task"] = string.format("%d", tpp)
     supported_types = _srun_get_mpi_types()
     if supported_types["pmi2"] then
         opts["mpi"] = "pmi2"
@@ -884,10 +889,10 @@ local function getMpiExec(mpitype)
 end
 
 local function getOmpType()
-    local cmd = string.format("ldd %s 2>/dev/null", executable[1])
+    local cmd = string.format("ldd %s 2>/dev/null", execList[1])
     local f = io.popen(cmd, 'r')
     if f == nil then
-        cmd = string.format("ldd $(basename %s) 2>/dev/null", executable[1])
+        cmd = string.format("ldd $(basename %s) 2>/dev/null", execList[1])
         f = io.popen(cmd, 'r')
     end
     omptype = nil
@@ -1025,6 +1030,12 @@ local function assignHosts(hosts, np, ppn, tpp)
                 break
             elseif tmp < ppn*tpp then
                 ppn = tmp
+                if tpp > 1 then
+                    ppn = math.tointeger(tmp/tpp)
+                end
+                if slurm_involved then
+                    slurm_no_tasks_per_node = true
+                end
             end
         end
         if break_while then
@@ -2188,7 +2199,20 @@ for opt,arg in likwid.getopt(arg,  cmd_options) do
         outfile = arg
         print_stderr("WARN: The output file option is currently ignored. Will be available in upcoming releases")
     elseif opt == "s" or opt == "skip" then
-        skipStr = "-s "..arg
+        local skip_mask = nil
+        if arg:match("0x[0-9A-Fa-f]") then
+            skip_mask = arg
+        else
+            if arg:match("[0-9A-Fa-f]") then
+                print_stderr("Given skip mask looks like hex, sanitizing arg to 0x"..arg)
+                skip_mask = "0x"..arg
+            else
+                print_stderr("Skip mask must be given in hex, ignoring setting")
+            end
+        end
+        if skip_mask ~= nil then
+            skipStr = "-s "..skip_mask
+        end
     elseif opt == "mpiopts" then
         mpiopts = tostring(arg)
     elseif opt == "?" then
@@ -2213,22 +2237,33 @@ if use_marker and #perf == 0 then
     mpirun_exit(1)
 end
 
-for i,x in pairs(arg) do
+local gotCommand = false
+for i = 1, #arg do
     if i > 0 then
-        table.insert(executable, abspath(x) or x)
+        local x = arg[i]
+        local t = x
+        if not gotCommand then
+            t = abspath(x) or x
+        end
+        if t ~= x then gotCommand = true end
+        if string.find(t, " ") then
+            table.insert(execList, "\""..t.."\"")
+        else
+            table.insert(execList, t)
+        end
     end
 end
 
-if #executable == 0 then
+if #execList == 0 then
     print_stderr("ERROR: No executable given on commandline")
     mpirun_exit(1)
 end
 
 if debug then
-    print_stdout("DEBUG: Executable given on commandline: "..table.concat(executable, " "))
+    print_stdout("DEBUG: Executable given on commandline: "..table.concat(execList, " "))
 end
 local gotExecutable = false
-for i,x in pairs(executable) do
+for i,x in pairs(execList) do
     if likwid.access(x, "x") == 0 then
         gotExecutable = true
         break
@@ -2236,7 +2271,7 @@ for i,x in pairs(executable) do
 end
 if not gotExecutable then
     print_stderr("ERROR: Cannot find an executable on commandline")
-    print_stderr(table.concat(executable, " "))
+    print_stderr(table.concat(execList, " "))
     mpirun_exit(1)
 end
 
@@ -2265,6 +2300,19 @@ if (mpiexecutable == nil) then
     mpirun_exit(1)
 end
 
+if mpitype == "slurm" then
+    local scontrol = abspath("scontrol")
+    if scontrol == nil then
+        print_stderr("Cannot find SLURM's scontrol command")
+        mpirun_exit(1)
+    end
+    local srun = abspath("srun")
+    if srun == nil then
+        print_stderr("Cannot find SLURM's srun command")
+        mpirun_exit(1)
+    end
+end
+
 if omptype == nil then
     omptype = getOmpType()
     if debug and omptype ~= nil then
@@ -2296,6 +2344,10 @@ if not hostfile then
 else
     hosts = readHostfile(hostfile)
 end
+if #hosts == 0 then
+    print_stderr("Cannot read list of hosts from environment or hostfile")
+    mpirun_exit(1)
+end
 
 local givenNrNodes = getNumberOfNodes(hosts)
 
@@ -2505,7 +2557,7 @@ if writeHostfile == nil or getEnvironment == nil or executeCommand == nil then
 end
 
 writeHostfile(newhosts, hostfilename)
-local skipped_ranks = writeWrapperScript(scriptfilename, table.concat(executable, " "), newhosts, envsettings, outfilename)
+local skipped_ranks = writeWrapperScript(scriptfilename, table.concat(execList, " "), newhosts, envsettings, outfilename)
 local env = getEnvironment()
 local exitvalue = executeCommand(scriptfilename, hostfilename, env, nrNodes)
 
