@@ -7,13 +7,13 @@
  *      Description:  An application to use the timeline mode of likwid-perfctr to generate
  *                    realtime plots using feedGnuplot
  *
- *      Version:   5.2.1
- *      Released:  03.12.2021
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2021 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -228,7 +228,11 @@ for opt,arg in likwid.getopt(arg, {"h","v","V:","g:","C:","c:","t:","r:","a","d"
 end
 local execList = {}
 for i=1, likwid.tablelength(arg)-2 do
-    table.insert(execList, arg[i])
+    if string.find(arg[i], " ") then
+        table.insert(execList, "\""..arg[i].."\"")
+    else
+        table.insert(execList, arg[i])
+    end
 end
 
 if print_configs then
