@@ -6,13 +6,13 @@
  *
  *      Description:  An application to pin a program including threads
  *
- *      Version:   5.1.0
- *      Released:  20.11.2020
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2020 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -83,7 +83,7 @@ local function usage()
     print_stdout("-c/-C <list>\t\t Comma separated processor IDs or expression")
     print_stdout("-s, --skip <hex>\t Bitmask with threads to skip")
     print_stdout("-p\t\t\t Print available domains with mapping on physical IDs")
-    print_stdout("\t\t\t If used together with -p option outputs a physical processor IDs.")
+    print_stdout("\t\t\t If used together with -c option outputs the list of physical processor IDs.")
     print_stdout("-d <string>\t\t Delimiter used for using -p to output physical processor list, default is comma.")
     print_stdout("-q, --quiet\t\t Silent without output")
     print_stdout("\n")
@@ -140,12 +140,17 @@ for opt,arg in likwid.getopt(arg, {"c:", "C:", "d:", "h", "i", "m", "p", "q", "s
     elseif (opt == "p") then
         print_domains = true
     elseif opt == "s" or opt == "skip" then
-        local s,e = arg:find("0x")
-        if s == nil then
-            print_stderr("Skip mask must be given in hex, hence start with 0x")
-            close_and_exit(1)
+        if arg:match("0x[0-9A-Fa-f]") then
+            skip_mask = arg
+        else
+            if arg:match("[0-9A-Fa-f]") then
+                print_stderr("Given skip mask looks like hex, sanitizing arg to 0x"..arg)
+                skip_mask = "0x"..arg
+            else
+                print_stderr("Skip mask must be given in hex")
+                close_and_exit(1)
+            end
         end
-        skip_mask = arg
     elseif opt == "q" or opt == "quiet" then
         likwid.setenv("LIKWID_SILENT","true")
         quiet = 1
@@ -159,7 +164,11 @@ for opt,arg in likwid.getopt(arg, {"c:", "C:", "d:", "h", "i", "m", "p", "q", "s
 end
 local execList = {}
 for i=1, likwid.tablelength(arg)-2 do
-    table.insert(execList, arg[i])
+    if string.find(arg[i], " ") then
+        table.insert(execList, "\""..arg[i].."\"")
+    else
+        table.insert(execList, arg[i])
+    end
 end
 
 likwid.setenv("LIKWID_NO_ACCESS", "1")
@@ -252,6 +261,11 @@ if omp_threads and tonumber(omp_threads) < num_threads then
 end
 
 likwid.setenv("KMP_AFFINITY","disabled")
+local likwid_hwthreads = {}
+for i=1,#cpu_list do
+    table.insert(likwid_hwthreads, tostring(math.tointeger(cpu_list[i])))
+end
+likwid.setenv("LIKWID_HWTHREADS", table.concat(likwid_hwthreads, ","))
 
 if os.getenv("CILK_NWORKERS") == nil then
     likwid.setenv("CILK_NWORKERS", tostring(math.tointeger(num_threads)))
@@ -275,7 +289,7 @@ if num_threads > 1 then
         likwid.setenv("LD_PRELOAD",likwid.pinlibpath .. ":" .. preload)
     end
     local ldpath = os.getenv("LD_LIBRARY_PATH")
-    local libpath = likwid.pinlibpath:match("([/%g]+)/%g+.so")
+    local libpath = likwid.pinlibpath:match("([^%s]+)/[^%s]+.so")
     if ldpath == nil then
         likwid.setenv("LD_LIBRARY_PATH", libpath)
     elseif libpath and not ldpath:match(libpath) then
@@ -300,9 +314,9 @@ if verbose > 0 and quiet == 0 then
     end
     print_stdout(string.format("Using %d thread(s) (cpuset: 0x%x)", num_threads, mask))
 end
-local pid = likwid.startProgram(exec, num_threads, cpu_list)
+local pid = likwid.startProgram(table.concat(execList," "), num_threads, cpu_list)
 if (pid == nil) then
-    print_stderr("Failed to execute command: ".. table.concat(execList," "))
+    print_stderr("Failed to execute command: ".. exec)
     close_and_exit(1)
 end
 
