@@ -7,13 +7,13 @@
  *      Description:  An application to get information about power
  *      consumption on architectures implementing the RAPL interface.
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -160,14 +160,14 @@ after = {}
 sock_cpulist = {}
 if #sockets == 0 then
     for i, domain in pairs(affinity["domains"]) do
-        if domain["tag"]:match("S%d+") then
+        if domain["tag"]:match("S%d+") and domain["numberOfProcessors"] > 0 then
             sid = domain["tag"]:match("S(%d+)")
             table.insert(sockets, sid)
         end
     end
 end
 for i, sid in pairs(sockets) do
-    pin = string.format("S%s:0-%d", tostring(sid), cputopo["numCoresPerSocket"]-1)
+    pin = string.format("S%s", tostring(sid))
     _, sock_cpulist[sid] = likwid.cpustr_to_cpulist(pin)
     before[sock_cpulist[sid][1]] = {}
     after[sock_cpulist[sid][1]] = {}
@@ -279,7 +279,11 @@ if #arg == 0 then
     end
 else
     for i=1, likwid.tablelength(arg)-2 do
-        table.insert(execList, arg[i])
+        if string.find(arg[i], " ") then
+            table.insert(execList, "\""..arg[i].."\"")
+        else
+            table.insert(execList, arg[i])
+        end
     end
     execString = execString .. table.concat(execList," ")
 end
