@@ -9,13 +9,13 @@
  *                  Allows to turn on and off the Hardware prefetcher
  *                  available.
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -201,6 +201,7 @@ cpuFeatures_update(int cpu)
             (cpuid_info.model == ROCKETLAKE) ||
             (cpuid_info.model == ICELAKEX1) ||
             (cpuid_info.model == ICELAKEX2) ||
+            (cpuid_info.model == SAPPHIRERAPIDS) ||
             (cpuid_info.model == ATOM_SILVERMONT_GOLD) ||
             (cpuid_info.model == CANNONLAKE) ||
             (cpuid_info.model == COMETLAKE1) ||
@@ -383,6 +384,7 @@ cpuFeatures_enable(int cpu, CpuFeature type, int print)
             (cpuid_info.model == COMETLAKE2) ||
             (cpuid_info.model == ICELAKE1) ||
             (cpuid_info.model == ICELAKE2) ||
+            (cpuid_info.model == SAPPHIRERAPIDS) ||
             (cpuid_info.model == ROCKETLAKE) ||
             (cpuid_info.model == ICELAKEX1) ||
             (cpuid_info.model == ICELAKEX2) ||
@@ -547,6 +549,7 @@ cpuFeatures_disable(int cpu, CpuFeature type, int print)
             (cpuid_info.model == COMETLAKE2) ||
             (cpuid_info.model == ICELAKE1) ||
             (cpuid_info.model == ICELAKE2) ||
+            (cpuid_info.model == SAPPHIRERAPIDS) ||
             (cpuid_info.model == ROCKETLAKE) ||
             (cpuid_info.model == ICELAKEX1) ||
             (cpuid_info.model == ICELAKEX2) ||
