@@ -5,14 +5,14 @@
  *
  *      Description:  Central error handling macros
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -93,6 +93,12 @@
         fflush(stdout); \
     }
 
+#define ROCMON_DEBUG_PRINT(lev, fmt, ...) \
+    if ((lev >= 0) && (lev <= likwid_rocmon_verbosity)) { \
+        fprintf(stdout, "ROCMON DEBUG - [%s:%d] " str(fmt) "\n", __func__, __LINE__,##__VA_ARGS__); \
+        fflush(stdout); \
+    }
+
 #define DEBUG_PLAIN_PRINT(lev, msg) \
     if ((lev >= 0) && (lev <= perfmon_verbosity)) { \
         fprintf(stdout, "DEBUG - [%s:%d] " str(msg) "\n",__func__, __LINE__);  \
@@ -109,6 +115,11 @@
     { \
         fprintf(stdout, "INFO - " STRINGIFY(fmt) "\n", ##__VA_ARGS__); \
     }
+#define ROCMON_INFO_PRINT(fmt, ...) \
+    if (likwid_rocmon_verbosity >= DEBUGLEV_INFO) \
+    { \
+        fprintf(stdout, "ROCMON INFO - " STRINGIFY(fmt) "\n", ##__VA_ARGS__); \
+    }
 
 #define TODO_PRINT(fmt, ...)  \
     fprintf(stdout, "TODO - " STRINGIFY(fmt) "\n", ##__VA_ARGS__);
