@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of nvmon module (NVML backend).
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Thomas Gruber (tg), thomas.gruber@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -30,21 +30,22 @@
 #ifndef LIKWID_NVMON_NVML_H
 #define LIKWID_NVMON_NVML_H
 
+#include <nvmon_types.h>
 
-
-
-
-
-NvmonFunctions nvmon_nvml_functions = {
-    .freeDevice = NULL,
-    .createDevice = NULL,
-    .getEventList = NULL,
-    .addEvents = NULL,
-    .setupCounters = NULL,
-    .startCounters = NULL,
-    .readCounters = NULL,
-};
-
-
+int nvml_init();
+void nvml_finalize();
+int nvml_getEventsOfGpu(int gpuId, NvmonEventList_t* output);
+void nvml_returnEventsOfGpu(NvmonEventList_t list);
+int nvml_addEventSet(char** events, int numEvents);
+int nvml_setupCounters(int gid);
+int nvml_startCounters();
+int nvml_stopCounters();
+int nvml_readCounters();
+int nvml_getNumberOfEvents(int groupId);
+double nvml_getResult(int gpuIdx, int groupId, int eventId);
+double nvml_getLastResult(int gpuIdx, int groupId, int eventId);
+double nvml_getTimeOfGroup(int groupId);
+double nvml_getLastTimeOfGroup(int groupId);
+double nvml_getTimeToLastReadOfGroup(int groupId);
 
 #endif /* LIKWID_NVMON_NVML_H */
