@@ -7,13 +7,13 @@
  *                    Configures and reads out performance counters
  *                    on NVIDIA GPUs. Supports multi GPUs.
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Thomas Gruber (tg), thomas.gruber@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -175,6 +175,15 @@ typedef struct {
 } NvmonFunctions;
 
 
+#define NVMON_SOURCE_BACKEND 0
+#define NVMON_SOURCE_NVML 1
+typedef struct {
+    int numEvents;
+    int* sourceTypes;
+    int* sourceIds;
+} NvmonGroupSourceInfo;
+
+
 /*! \brief Structure specifying all performance monitoring event groups
 
 The global NvmonGroupSet structure holds all eventSets and threads that are
@@ -192,6 +201,9 @@ typedef struct {
     NvmonDevice*     gpus; /*!< \brief List of GPUs */
     int              numberOfBackends;
     NvmonFunctions*  backends[3];
+
+    int                   numGroupSources;
+    NvmonGroupSourceInfo* groupSources;
 } NvmonGroupSet;
 
 extern NvmonGroupSet* nvGroupSet;
