@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of perfmon module for Intel Icelake.
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -402,7 +402,7 @@ int icx_cbox_setup(int cpu_id, RegisterIndex index, PerfmonEvent *event)
     {
         case 0x36:
         case 0x35:
-            umask_ext_mask = 0x1FFFFF;
+            umask_ext_mask = 0xFFFFFF;
             break;
         case 0x34:
             umask_ext_mask = 0x1FFF;
