@@ -5,13 +5,13 @@
  *
  *      Description:  Counter Header File of perfmon module for Intel Icelake X.
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -86,30 +86,30 @@ static RegisterMap icelakeX_counter_map[NUM_COUNTERS_ICELAKEX] = {
     {"MBOX1C1", PMC28, MBOX1, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_0_CH_1, EVENT_OPTION_NONE_MASK},
     {"MBOX1C2", PMC29, MBOX1, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_0_CH_1, EVENT_OPTION_NONE_MASK},
     {"MBOX1C3", PMC30, MBOX1, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_0_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX2C0", PMC31, MBOX2, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_1_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX2C1", PMC32, MBOX2, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_1_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX2C2", PMC33, MBOX2, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_1_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX2C3", PMC34, MBOX2, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_1_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX3C0", PMC35, MBOX3, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_1_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX3C1", PMC36, MBOX3, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_1_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX3C2", PMC37, MBOX3, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_1_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX3C3", PMC38, MBOX3, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_1_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX4C0", PMC39, MBOX4, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_2_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX4C1", PMC40, MBOX4, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_2_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX4C2", PMC41, MBOX4, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_2_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX4C3", PMC42, MBOX4, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_2_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX5C0", PMC43, MBOX5, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_2_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX5C1", PMC44, MBOX5, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_2_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX5C2", PMC45, MBOX5, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_2_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX5C3", PMC46, MBOX5, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_2_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX6C0", PMC47, MBOX6, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_3_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX6C1", PMC48, MBOX6, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_3_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX6C2", PMC49, MBOX6, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_3_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX6C3", PMC50, MBOX6, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_3_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX7C0", PMC51, MBOX7, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_3_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX7C1", PMC52, MBOX7, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_3_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX7C2", PMC53, MBOX7, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_3_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX7C3", PMC54, MBOX7, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_3_CH_1, EVENT_OPTION_NONE_MASK},
+    {"MBOX2C0", PMC31, MBOX2, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_0_CH_2, EVENT_OPTION_NONE_MASK},
+    {"MBOX2C1", PMC32, MBOX2, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_0_CH_2, EVENT_OPTION_NONE_MASK},
+    {"MBOX2C2", PMC33, MBOX2, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_0_CH_2, EVENT_OPTION_NONE_MASK},
+    {"MBOX2C3", PMC34, MBOX2, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_0_CH_2, EVENT_OPTION_NONE_MASK},
+    {"MBOX3C0", PMC35, MBOX3, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_0_CH_3, EVENT_OPTION_NONE_MASK},
+    {"MBOX3C1", PMC36, MBOX3, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_0_CH_3, EVENT_OPTION_NONE_MASK},
+    {"MBOX3C2", PMC37, MBOX3, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_0_CH_3, EVENT_OPTION_NONE_MASK},
+    {"MBOX3C3", PMC38, MBOX3, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_0_CH_3, EVENT_OPTION_NONE_MASK},
+    {"MBOX4C0", PMC39, MBOX4, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_0_CH_4, EVENT_OPTION_NONE_MASK},
+    {"MBOX4C1", PMC40, MBOX4, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_0_CH_4, EVENT_OPTION_NONE_MASK},
+    {"MBOX4C2", PMC41, MBOX4, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_0_CH_4, EVENT_OPTION_NONE_MASK},
+    {"MBOX4C3", PMC42, MBOX4, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_0_CH_4, EVENT_OPTION_NONE_MASK},
+    {"MBOX5C0", PMC43, MBOX5, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_0_CH_5, EVENT_OPTION_NONE_MASK},
+    {"MBOX5C1", PMC44, MBOX5, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_0_CH_5, EVENT_OPTION_NONE_MASK},
+    {"MBOX5C2", PMC45, MBOX5, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_0_CH_5, EVENT_OPTION_NONE_MASK},
+    {"MBOX5C3", PMC46, MBOX5, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_0_CH_5, EVENT_OPTION_NONE_MASK},
+    {"MBOX6C0", PMC47, MBOX6, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_0_CH_6, EVENT_OPTION_NONE_MASK},
+    {"MBOX6C1", PMC48, MBOX6, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_0_CH_6, EVENT_OPTION_NONE_MASK},
+    {"MBOX6C2", PMC49, MBOX6, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_0_CH_6, EVENT_OPTION_NONE_MASK},
+    {"MBOX6C3", PMC50, MBOX6, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_0_CH_6, EVENT_OPTION_NONE_MASK},
+    {"MBOX7C0", PMC51, MBOX7, MMIO_ICX_IMC_BOX_CTL0, MMIO_ICX_IMC_BOX_CTR0, 0, MMIO_IMC_DEVICE_0_CH_7, EVENT_OPTION_NONE_MASK},
+    {"MBOX7C1", PMC52, MBOX7, MMIO_ICX_IMC_BOX_CTL1, MMIO_ICX_IMC_BOX_CTR1, 0, MMIO_IMC_DEVICE_0_CH_7, EVENT_OPTION_NONE_MASK},
+    {"MBOX7C2", PMC53, MBOX7, MMIO_ICX_IMC_BOX_CTL2, MMIO_ICX_IMC_BOX_CTR2, 0, MMIO_IMC_DEVICE_0_CH_7, EVENT_OPTION_NONE_MASK},
+    {"MBOX7C3", PMC54, MBOX7, MMIO_ICX_IMC_BOX_CTL3, MMIO_ICX_IMC_BOX_CTR3, 0, MMIO_IMC_DEVICE_0_CH_7, EVENT_OPTION_NONE_MASK},
     {"CBOX0C0", PMC55, CBOX0, MSR_UNC_ICX_C0_PMON_CTL0, MSR_UNC_ICX_C0_PMON_CTR0, 0, MSR_DEV, ICX_VALID_OPTIONS_CBOX},
     {"CBOX0C1", PMC56, CBOX0, MSR_UNC_ICX_C0_PMON_CTL1, MSR_UNC_ICX_C0_PMON_CTR1, 0, MSR_DEV, ICX_VALID_OPTIONS_CBOX},
     {"CBOX0C2", PMC57, CBOX0, MSR_UNC_ICX_C0_PMON_CTL2, MSR_UNC_ICX_C0_PMON_CTR2, 0, MSR_DEV, ICX_VALID_OPTIONS_CBOX},
@@ -457,12 +457,12 @@ static RegisterMap icelakeX_counter_map[NUM_COUNTERS_ICELAKEX] = {
     {"MDEV3C4", PMC399, MDEV3, 0, MMIO_ICX_IMC_FREERUN_DCLK, 0, MMIO_IMC_DEVICE_3_FREERUN, EVENT_OPTION_NONE_MASK},
     {"MBOX0FIX", PMC400, MBOX0FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_0_CH_0, EVENT_OPTION_NONE_MASK},
     {"MBOX1FIX", PMC401, MBOX1FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_0_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX2FIX", PMC402, MBOX2FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_1_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX3FIX", PMC403, MBOX3FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_1_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX4FIX", PMC404, MBOX4FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_2_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX5FIX", PMC405, MBOX5FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_2_CH_1, EVENT_OPTION_NONE_MASK},
-    {"MBOX5FIX", PMC406, MBOX6FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_3_CH_0, EVENT_OPTION_NONE_MASK},
-    {"MBOX7FIX", PMC407, MBOX7FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_3_CH_1, EVENT_OPTION_NONE_MASK},
+    {"MBOX2FIX", PMC402, MBOX2FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_0_CH_2, EVENT_OPTION_NONE_MASK},
+    {"MBOX3FIX", PMC403, MBOX3FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_0_CH_3, EVENT_OPTION_NONE_MASK},
+    {"MBOX4FIX", PMC404, MBOX4FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_0_CH_4, EVENT_OPTION_NONE_MASK},
+    {"MBOX5FIX", PMC405, MBOX5FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_0_CH_5, EVENT_OPTION_NONE_MASK},
+    {"MBOX5FIX", PMC406, MBOX6FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_0_CH_6, EVENT_OPTION_NONE_MASK},
+    {"MBOX7FIX", PMC407, MBOX7FIX, MMIO_ICX_IMC_BOX_CLK_CTL, MMIO_ICX_IMC_BOX_CLK_CTR, 0, MMIO_IMC_DEVICE_0_CH_7, EVENT_OPTION_NONE_MASK},
 };
 
 
@@ -475,20 +475,20 @@ static BoxMap icelakeX_box_map[NUM_UNITS] = {
     [METRICS] = {0, MSR_V4_PERF_GLOBAL_STATUS, MSR_V4_PERF_GLOBAL_STATUS, 48, 0, 0, 8},
     [MBOX0] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_0, 48, 0},
     [MBOX1] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_1, 48, 0},
-    [MBOX2] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_1_CH_0, 48, 0},
-    [MBOX3] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_1_CH_1, 48, 0},
-    [MBOX4] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_2_CH_0, 48, 0},
-    [MBOX5] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_2_CH_1, 48, 0},
-    [MBOX6] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_3_CH_0, 48, 0},
-    [MBOX7] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_3_CH_1, 48, 0},
+    [MBOX2] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_2, 48, 0},
+    [MBOX3] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_3, 48, 0},
+    [MBOX4] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_4, 48, 0},
+    [MBOX5] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_5, 48, 0},
+    [MBOX6] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_6, 48, 0},
+    [MBOX7] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_7, 48, 0},
     [MBOX0FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_0, 48, 0},
     [MBOX1FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_1, 48, 0},
-    [MBOX2FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_1_CH_0, 48, 0},
-    [MBOX3FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_1_CH_1, 48, 0},
-    [MBOX4FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_2_CH_0, 48, 0},
-    [MBOX5FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_2_CH_1, 48, 0},
-    [MBOX6FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_3_CH_0, 48, 0},
-    [MBOX7FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_3_CH_1, 48, 0},
+    [MBOX2FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_2, 48, 0},
+    [MBOX3FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_3, 48, 0},
+    [MBOX4FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_4, 48, 0},
+    [MBOX5FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_5, 48, 0},
+    [MBOX6FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_6, 48, 0},
+    [MBOX7FIX] = {MMIO_ICX_IMC_BOX_CTRL, MMIO_ICX_IMC_BOX_STATUS, MMIO_ICX_IMC_BOX_STATUS,0, 1, MMIO_IMC_DEVICE_0_CH_7, 48, 0},
     [MDEV0] = {0, 0, 0, 0, 1, MMIO_IMC_DEVICE_0_FREERUN, 64},
     [MDEV1] = {0, 0, 0, 0, 1, MMIO_IMC_DEVICE_1_FREERUN, 64},
     [MDEV2] = {0, 0, 0, 0, 1, MMIO_IMC_DEVICE_2_FREERUN, 64},
@@ -586,12 +586,12 @@ static PciDevice icelakeX_pci_devices[MAX_NUM_PCI_DEVICES] = {
  [MSR_DEV] = {NODEVTYPE, "", "MSR", ""},
  [MMIO_IMC_DEVICE_0_CH_0] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX0", 0x3451},
  [MMIO_IMC_DEVICE_0_CH_1] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX1", 0x3451},
- [MMIO_IMC_DEVICE_1_CH_0] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX2", 0x3451},
- [MMIO_IMC_DEVICE_1_CH_1] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX3", 0x3451},
- [MMIO_IMC_DEVICE_2_CH_0] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX4", 0x3451},
- [MMIO_IMC_DEVICE_2_CH_1] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX5", 0x3451},
- [MMIO_IMC_DEVICE_3_CH_0] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX6", 0x3451},
- [MMIO_IMC_DEVICE_3_CH_1] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX7", 0x3451},
+ [MMIO_IMC_DEVICE_0_CH_2] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX2", 0x3451},
+ [MMIO_IMC_DEVICE_0_CH_3] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX3", 0x3451},
+ [MMIO_IMC_DEVICE_0_CH_4] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX4", 0x3451},
+ [MMIO_IMC_DEVICE_0_CH_5] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX5", 0x3451},
+ [MMIO_IMC_DEVICE_0_CH_6] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX6", 0x3451},
+ [MMIO_IMC_DEVICE_0_CH_7] = {IMC, NULL, "MMAP_IMC_DEVICE", "MBOX7", 0x3451},
  [MMIO_IMC_DEVICE_0_FREERUN]= {IMC, NULL, "MMAP_IMC_FREERUN_DEVICE", "MDEV0", 0x3451},
  [MMIO_IMC_DEVICE_1_FREERUN]= {IMC, NULL, "MMAP_IMC_FREERUN_DEVICE", "MDEV1", 0x3451},
  [MMIO_IMC_DEVICE_2_FREERUN]= {IMC, NULL, "MMAP_IMC_FREERUN_DEVICE", "MDEV2", 0x3451},
@@ -628,46 +628,46 @@ static char* icelakeX_translate_types[NUM_UNITS] = {
     [MBOX5FIX] = "/sys/bus/event_source/devices/uncore_imc_5",
     [MBOX6FIX] = "/sys/bus/event_source/devices/uncore_imc_6",
     [MBOX7FIX] = "/sys/bus/event_source/devices/uncore_imc_7",
-    [CBOX0] = "/sys/bus/event_source/devices/uncore_cbox_0",
-    [CBOX1] = "/sys/bus/event_source/devices/uncore_cbox_1",
-    [CBOX2] = "/sys/bus/event_source/devices/uncore_cbox_2",
-    [CBOX3] = "/sys/bus/event_source/devices/uncore_cbox_3",
-    [CBOX4] = "/sys/bus/event_source/devices/uncore_cbox_4",
-    [CBOX5] = "/sys/bus/event_source/devices/uncore_cbox_5",
-    [CBOX6] = "/sys/bus/event_source/devices/uncore_cbox_6",
-    [CBOX7] = "/sys/bus/event_source/devices/uncore_cbox_7",
-    [CBOX8] = "/sys/bus/event_source/devices/uncore_cbox_8",
-    [CBOX9] = "/sys/bus/event_source/devices/uncore_cbox_9",
-    [CBOX10] = "/sys/bus/event_source/devices/uncore_cbox_10",
-    [CBOX11] = "/sys/bus/event_source/devices/uncore_cbox_11",
-    [CBOX12] = "/sys/bus/event_source/devices/uncore_cbox_12",
-    [CBOX13] = "/sys/bus/event_source/devices/uncore_cbox_13",
-    [CBOX14] = "/sys/bus/event_source/devices/uncore_cbox_14",
-    [CBOX15] = "/sys/bus/event_source/devices/uncore_cbox_15",
-    [CBOX16] = "/sys/bus/event_source/devices/uncore_cbox_16",
-    [CBOX17] = "/sys/bus/event_source/devices/uncore_cbox_17",
-    [CBOX18] = "/sys/bus/event_source/devices/uncore_cbox_18",
-    [CBOX19] = "/sys/bus/event_source/devices/uncore_cbox_19",
-    [CBOX20] = "/sys/bus/event_source/devices/uncore_cbox_20",
-    [CBOX21] = "/sys/bus/event_source/devices/uncore_cbox_21",
-    [CBOX22] = "/sys/bus/event_source/devices/uncore_cbox_22",
-    [CBOX23] = "/sys/bus/event_source/devices/uncore_cbox_23",
-    [CBOX24] = "/sys/bus/event_source/devices/uncore_cbox_24",
-    [CBOX25] = "/sys/bus/event_source/devices/uncore_cbox_25",
-    [CBOX26] = "/sys/bus/event_source/devices/uncore_cbox_26",
-    [CBOX27] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX28] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX29] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX30] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX31] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX32] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX33] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX34] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX35] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX36] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX37] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX38] = "/sys/bus/event_source/devices/uncore_cbox_27",
-    [CBOX39] = "/sys/bus/event_source/devices/uncore_cbox_27",
+    [CBOX0] = "/sys/bus/event_source/devices/uncore_cha_0",
+    [CBOX1] = "/sys/bus/event_source/devices/uncore_cha_1",
+    [CBOX2] = "/sys/bus/event_source/devices/uncore_cha_2",
+    [CBOX3] = "/sys/bus/event_source/devices/uncore_cha_3",
+    [CBOX4] = "/sys/bus/event_source/devices/uncore_cha_4",
+    [CBOX5] = "/sys/bus/event_source/devices/uncore_cha_5",
+    [CBOX6] = "/sys/bus/event_source/devices/uncore_cha_6",
+    [CBOX7] = "/sys/bus/event_source/devices/uncore_cha_7",
+    [CBOX8] = "/sys/bus/event_source/devices/uncore_cha_8",
+    [CBOX9] = "/sys/bus/event_source/devices/uncore_cha_9",
+    [CBOX10] = "/sys/bus/event_source/devices/uncore_cha_10",
+    [CBOX11] = "/sys/bus/event_source/devices/uncore_cha_11",
+    [CBOX12] = "/sys/bus/event_source/devices/uncore_cha_12",
+    [CBOX13] = "/sys/bus/event_source/devices/uncore_cha_13",
+    [CBOX14] = "/sys/bus/event_source/devices/uncore_cha_14",
+    [CBOX15] = "/sys/bus/event_source/devices/uncore_cha_15",
+    [CBOX16] = "/sys/bus/event_source/devices/uncore_cha_16",
+    [CBOX17] = "/sys/bus/event_source/devices/uncore_cha_17",
+    [CBOX18] = "/sys/bus/event_source/devices/uncore_cha_18",
+    [CBOX19] = "/sys/bus/event_source/devices/uncore_cha_19",
+    [CBOX20] = "/sys/bus/event_source/devices/uncore_cha_20",
+    [CBOX21] = "/sys/bus/event_source/devices/uncore_cha_21",
+    [CBOX22] = "/sys/bus/event_source/devices/uncore_cha_22",
+    [CBOX23] = "/sys/bus/event_source/devices/uncore_cha_23",
+    [CBOX24] = "/sys/bus/event_source/devices/uncore_cha_24",
+    [CBOX25] = "/sys/bus/event_source/devices/uncore_cha_25",
+    [CBOX26] = "/sys/bus/event_source/devices/uncore_cha_26",
+    [CBOX27] = "/sys/bus/event_source/devices/uncore_cha_27",
+    [CBOX28] = "/sys/bus/event_source/devices/uncore_cha_28",
+    [CBOX29] = "/sys/bus/event_source/devices/uncore_cha_29",
+    [CBOX30] = "/sys/bus/event_source/devices/uncore_cha_30",
+    [CBOX31] = "/sys/bus/event_source/devices/uncore_cha_31",
+    [CBOX32] = "/sys/bus/event_source/devices/uncore_cha_32",
+    [CBOX33] = "/sys/bus/event_source/devices/uncore_cha_33",
+    [CBOX34] = "/sys/bus/event_source/devices/uncore_cha_34",
+    [CBOX35] = "/sys/bus/event_source/devices/uncore_cha_35",
+    [CBOX36] = "/sys/bus/event_source/devices/uncore_cha_36",
+    [CBOX37] = "/sys/bus/event_source/devices/uncore_cha_37",
+    [CBOX38] = "/sys/bus/event_source/devices/uncore_cha_38",
+    [CBOX39] = "/sys/bus/event_source/devices/uncore_cha_39",
     [BBOX0] = "/sys/bus/event_source/devices/uncore_m2m_0",
     [BBOX1] = "/sys/bus/event_source/devices/uncore_m2m_1",
     [BBOX2] = "/sys/bus/event_source/devices/uncore_m2m_2",
