@@ -5,14 +5,14 @@
  *
  *      Description:  Header File of registers.
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -98,8 +98,71 @@ typedef enum {
     PMC360, PMC361, PMC362, PMC363, PMC364, PMC365, PMC366, PMC367, PMC368, PMC369,
     PMC370, PMC371, PMC372, PMC373, PMC374, PMC375, PMC376, PMC377, PMC378, PMC379,
     PMC380, PMC381, PMC382, PMC383, PMC384, PMC385, PMC386, PMC387, PMC388, PMC389,
-    PMC390, PMC391, PMC392, PMC393, PMC394, PMC395, PMC396, PMC397, PMC398, PMC399, 
-    PMC400, PMC401, PMC402, PMC403, PMC404, PMC405, PMC406, PMC407, PMC408, PMC409, 
+    PMC390, PMC391, PMC392, PMC393, PMC394, PMC395, PMC396, PMC397, PMC398, PMC399,
+    PMC400, PMC401, PMC402, PMC403, PMC404, PMC405, PMC406, PMC407, PMC408, PMC409,
+    PMC410, PMC411, PMC412, PMC413, PMC414, PMC415, PMC416, PMC417, PMC418, PMC419,
+    PMC420, PMC421, PMC422, PMC423, PMC424, PMC425, PMC426, PMC427, PMC428, PMC429,
+    PMC430, PMC431, PMC432, PMC433, PMC434, PMC435, PMC436, PMC437, PMC438, PMC439,
+    PMC440, PMC441, PMC442, PMC443, PMC444, PMC445, PMC446, PMC447, PMC448, PMC449,
+    PMC450, PMC451, PMC452, PMC453, PMC454, PMC455, PMC456, PMC457, PMC458, PMC459,
+    PMC460, PMC461, PMC462, PMC463, PMC464, PMC465, PMC466, PMC467, PMC468, PMC469,
+    PMC470, PMC471, PMC472, PMC473, PMC474, PMC475, PMC476, PMC477, PMC478, PMC479,
+    PMC480, PMC481, PMC482, PMC483, PMC484, PMC485, PMC486, PMC487, PMC488, PMC489,
+    PMC490, PMC491, PMC492, PMC493, PMC494, PMC495, PMC496, PMC497, PMC498, PMC499,
+    PMC500, PMC501, PMC502, PMC503, PMC504, PMC505, PMC506, PMC507, PMC508, PMC509,
+    PMC510, PMC511, PMC512, PMC513, PMC514, PMC515, PMC516, PMC517, PMC518, PMC519,
+    PMC520, PMC521, PMC522, PMC523, PMC524, PMC525, PMC526, PMC527, PMC528, PMC529,
+    PMC530, PMC531, PMC532, PMC533, PMC534, PMC535, PMC536, PMC537, PMC538, PMC539,
+    PMC540, PMC541, PMC542, PMC543, PMC544, PMC545, PMC546, PMC547, PMC548, PMC549,
+    PMC550, PMC551, PMC552, PMC553, PMC554, PMC555, PMC556, PMC557, PMC558, PMC559,
+    PMC560, PMC561, PMC562, PMC563, PMC564, PMC565, PMC566, PMC567, PMC568, PMC569,
+    PMC570, PMC571, PMC572, PMC573, PMC574, PMC575, PMC576, PMC577, PMC578, PMC579,
+    PMC580, PMC581, PMC582, PMC583, PMC584, PMC585, PMC586, PMC587, PMC588, PMC589,
+    PMC590, PMC591, PMC592, PMC593, PMC594, PMC595, PMC596, PMC597, PMC598, PMC599,
+    PMC600, PMC601, PMC602, PMC603, PMC604, PMC605, PMC606, PMC607, PMC608, PMC609,
+    PMC610, PMC611, PMC612, PMC613, PMC614, PMC615, PMC616, PMC617, PMC618, PMC619,
+    PMC620, PMC621, PMC622, PMC623, PMC624, PMC625, PMC626, PMC627, PMC628, PMC629,
+    PMC630, PMC631, PMC632, PMC633, PMC634, PMC635, PMC636, PMC637, PMC638, PMC639,
+    PMC640, PMC641, PMC642, PMC643, PMC644, PMC645, PMC646, PMC647, PMC648, PMC649,
+    PMC650, PMC651, PMC652, PMC653, PMC654, PMC655, PMC656, PMC657, PMC658, PMC659,
+    PMC660, PMC661, PMC662, PMC663, PMC664, PMC665, PMC666, PMC667, PMC668, PMC669,
+    PMC670, PMC671, PMC672, PMC673, PMC674, PMC675, PMC676, PMC677, PMC678, PMC679,
+    PMC680, PMC681, PMC682, PMC683, PMC684, PMC685, PMC686, PMC687, PMC688, PMC689,
+    PMC690, PMC691, PMC692, PMC693, PMC694, PMC695, PMC696, PMC697, PMC698, PMC699,
+    PMC700, PMC701, PMC702, PMC703, PMC704, PMC705, PMC706, PMC707, PMC708, PMC709,
+    PMC710, PMC711, PMC712, PMC713, PMC714, PMC715, PMC716, PMC717, PMC718, PMC719,
+    PMC720, PMC721, PMC722, PMC723, PMC724, PMC725, PMC726, PMC727, PMC728, PMC729,
+    PMC730, PMC731, PMC732, PMC733, PMC734, PMC735, PMC736, PMC737, PMC738, PMC739,
+    PMC740, PMC741, PMC742, PMC743, PMC744, PMC745, PMC746, PMC747, PMC748, PMC749,
+    PMC750, PMC751, PMC752, PMC753, PMC754, PMC755, PMC756, PMC757, PMC758, PMC759,
+    PMC760, PMC761, PMC762, PMC763, PMC764, PMC765, PMC766, PMC767, PMC768, PMC769,
+    PMC770, PMC771, PMC772, PMC773, PMC774, PMC775, PMC776, PMC777, PMC778, PMC779,
+    PMC780, PMC781, PMC782, PMC783, PMC784, PMC785, PMC786, PMC787, PMC788, PMC789,
+    PMC790, PMC791, PMC792, PMC793, PMC794, PMC795, PMC796, PMC797, PMC798, PMC799,
+    PMC800, PMC801, PMC802, PMC803, PMC804, PMC805, PMC806, PMC807, PMC808, PMC809,
+    PMC810, PMC811, PMC812, PMC813, PMC814, PMC815, PMC816, PMC817, PMC818, PMC819,
+    PMC820, PMC821, PMC822, PMC823, PMC824, PMC825, PMC826, PMC827, PMC828, PMC829,
+    PMC830, PMC831, PMC832, PMC833, PMC834, PMC835, PMC836, PMC837, PMC838, PMC839,
+    PMC840, PMC841, PMC842, PMC843, PMC844, PMC845, PMC846, PMC847, PMC848, PMC849,
+    PMC850, PMC851, PMC852, PMC853, PMC854, PMC855, PMC856, PMC857, PMC858, PMC859,
+    PMC860, PMC861, PMC862, PMC863, PMC864, PMC865, PMC866, PMC867, PMC868, PMC869,
+    PMC870, PMC871, PMC872, PMC873, PMC874, PMC875, PMC876, PMC877, PMC878, PMC879,
+    PMC880, PMC881, PMC882, PMC883, PMC884, PMC885, PMC886, PMC887, PMC888, PMC889,
+    PMC890, PMC891, PMC892, PMC893, PMC894, PMC895, PMC896, PMC897, PMC898, PMC899,
+    PMC900, PMC901, PMC902, PMC903, PMC904, PMC905, PMC906, PMC907, PMC908, PMC909,
+    PMC910, PMC911, PMC912, PMC913, PMC914, PMC915, PMC916, PMC917, PMC918, PMC919,
+    PMC920, PMC921, PMC922, PMC923, PMC924, PMC925, PMC926, PMC927, PMC928, PMC929,
+    PMC930, PMC931, PMC932, PMC933, PMC934, PMC935, PMC936, PMC937, PMC938, PMC939,
+    PMC940, PMC941, PMC942, PMC943, PMC944, PMC945, PMC946, PMC947, PMC948, PMC949,
+    PMC950, PMC951, PMC952, PMC953, PMC954, PMC955, PMC956, PMC957, PMC958, PMC959,
+    PMC960, PMC961, PMC962, PMC963, PMC964, PMC965, PMC966, PMC967, PMC968, PMC969,
+    PMC970, PMC971, PMC972, PMC973, PMC974, PMC975, PMC976, PMC977, PMC978, PMC979,
+    PMC980, PMC981, PMC982, PMC983, PMC984, PMC985, PMC986, PMC987, PMC988, PMC989,
+    PMC990, PMC991, PMC992, PMC993, PMC994, PMC995, PMC996, PMC997, PMC998, PMC999,
+    PMC1000, PMC1001, PMC1002, PMC1003, PMC1004, PMC1005, PMC1006, PMC1007, PMC1008, PMC1009,
+    PMC1010, PMC1011, PMC1012, PMC1013, PMC1014, PMC1015, PMC1016, PMC1017, PMC1018, PMC1019,
+    PMC1020, PMC1021, PMC1022, PMC1023, PMC1024, PMC1025, PMC1026, PMC1027, PMC1028, PMC1029,
+    
     NUM_PMC
 } RegisterIndex;
 
@@ -109,16 +172,23 @@ typedef enum {
     MBOX1, MBOX2, MBOX3,
     MBOX4, MBOX5, MBOX6, MBOX7,
     MBOX8, MBOX9, MBOX10, MBOX11,
-    MBOX12,
+    MBOX12, MBOX13, MBOX14, MBOX15,
     MBOX0FIX, MBOX1FIX, MBOX2FIX,
     MBOX3FIX, MBOX4FIX, MBOX5FIX,
     MBOX6FIX, MBOX7FIX, MBOX8FIX,
     MBOX9FIX, MBOX10FIX, MBOX11FIX,
-    MBOX12FIX,
+    MBOX12FIX, MBOX13FIX, MBOX14FIX, MBOX15FIX,
     MDEV0, MDEV1, MDEV2, MDEV3,
     MBOX0TMP,
     BBOX0, BBOX1, BBOX2, BBOX3,
-    RBOX0, RBOX1, RBOX2,
+    BBOX4, BBOX5, BBOX6, BBOX7,
+    BBOX8, BBOX9, BBOX10, BBOX11,
+    BBOX12, BBOX13, BBOX14, BBOX15,
+    BBOX16, BBOX17, BBOX18, BBOX19,
+    BBOX20, BBOX21, BBOX22, BBOX23,
+    BBOX24, BBOX25, BBOX26, BBOX27,
+    BBOX28, BBOX29, BBOX30, BBOX31,
+    RBOX0, RBOX1, RBOX2, RBOX3,
     WBOX,
     WBOX0FIX, WBOX1FIX, WBOX2FIX, WBOX3FIX,
     SBOX0, SBOX1, SBOX2, SBOX3,
@@ -136,13 +206,20 @@ typedef enum {
     CBOX30, CBOX31, CBOX32,
     CBOX33, CBOX34, CBOX35,
     CBOX36, CBOX37, CBOX38, CBOX39,
-    PBOX, PBOX1, PBOX2, PBOX3, PBOX4, PBOX5,
+    CBOX40, CBOX41, CBOX42,
+    CBOX43, CBOX44, CBOX45,
+    CBOX46, CBOX47, CBOX48, CBOX49,
+    CBOX50, CBOX51, CBOX52,
+    CBOX53, CBOX54, CBOX55,
+    CBOX56, CBOX57, CBOX58, CBOX59,
+    PBOX, PBOX1, PBOX2, PBOX3, PBOX4, PBOX5, PBOX6, PBOX7, PBOX8, PBOX9, PBOX10, PBOX11, PBOX12, PBOX13, PBOX14, PBOX15,
     UBOX,
     UBOXFIX,
-    IBOX0, IBOX1, IBOX2, IBOX3, IBOX4, IBOX5,
-    IBOX0FIX, IBOX1FIX, IBOX2FIX, IBOX3FIX, IBOX4FIX, IBOX5FIX,
-    QBOX0, QBOX1, QBOX2,
-    QBOX0FIX, QBOX1FIX, QBOX2FIX,
+    IBOX0, IBOX1, IBOX2, IBOX3, IBOX4, IBOX5, IBOX6, IBOX7, IBOX8, IBOX9, IBOX10, IBOX11, IBOX12, IBOX13, IBOX14, IBOX15,
+    IBOX0FIX, IBOX1FIX, IBOX2FIX, IBOX3FIX, IBOX4FIX, IBOX5FIX, IBOX6FIX, IBOX7FIX, IBOX8FIX, IBOX9FIX, IBOX10FIX, IBOX11FIX, IBOX12FIX, IBOX13FIX, IBOX14FIX, IBOX15FIX,
+    IRP0, IRP1, IRP2, IRP3, IRP4, IRP5, IRP6, IRP7, IRP8, IRP9, IRP10, IRP11, IRP12, IRP13, IRP14, IRP15,
+    QBOX0, QBOX1, QBOX2, QBOX3,
+    QBOX0FIX, QBOX1FIX, QBOX2FIX, QBOX3FIX,
     EUBOX0, EUBOX0FIX, EUBOX1, EUBOX1FIX,
     EUBOX2, EUBOX2FIX, EUBOX3, EUBOX3FIX,
     EUBOX4, EUBOX4FIX, EUBOX5, EUBOX5FIX,
@@ -151,11 +228,37 @@ typedef enum {
     EDBOX2, EDBOX2FIX, EDBOX3, EDBOX3FIX,
     EDBOX4, EDBOX4FIX, EDBOX5, EDBOX5FIX,
     EDBOX6, EDBOX6FIX, EDBOX7, EDBOX7FIX,
+    IPMC, FPMC,
+    MDF0, MDF1, MDF2, MDF3,
+    MDF4, MDF5, MDF6, MDF7,
+    MDF8, MDF9, MDF10, MDF11,
+    MDF12, MDF13, MDF14, MDF15,
+    MDF16, MDF17, MDF18, MDF19,
+    MDF20, MDF21, MDF22, MDF23,
+    MDF24, MDF25, MDF26, MDF27,
+    MDF28, MDF29, MDF30, MDF31,
+    MDF32, MDF33, MDF34, MDF35,
+    MDF36, MDF37, MDF38, MDF39,
+    MDF40, MDF41, MDF42, MDF43,
+    MDF44, MDF45, MDF46, MDF47,
+    MDF48, MDF49, MDF50, MDF51,
+    HBM0, HBM0FIX, HBM1, HBM1FIX, HBM2, HBM2FIX, HBM3, HBM3FIX,
+    HBM4, HBM4FIX, HBM5, HBM5FIX, HBM6, HBM6FIX, HBM7, HBM7FIX,
+    HBM8, HBM8FIX, HBM9, HBM9FIX, HBM10, HBM10FIX, HBM11, HBM11FIX,
+    HBM12, HBM12FIX, HBM13, HBM13FIX, HBM14, HBM14FIX, HBM15, HBM15FIX,
+    HBM16, HBM16FIX, HBM17, HBM17FIX, HBM18, HBM18FIX, HBM19, HBM19FIX,
+    HBM20, HBM20FIX, HBM21, HBM21FIX, HBM22, HBM22FIX, HBM23, HBM23FIX,
+    HBM24, HBM24FIX, HBM25, HBM25FIX, HBM26, HBM26FIX, HBM27, HBM27FIX,
+    HBM28, HBM28FIX, HBM29, HBM29FIX, HBM30, HBM30FIX, HBM31, HBM31FIX,
     NUM_UNITS, NOTYPE, MAX_UNITS
 } RegisterType;
 
+#define PBOX0 PBOX
+
 static char* RegisterTypeNames[MAX_UNITS] = {
     [PMC] = "Core-local general purpose counters",
+    [IPMC] = "Core-local general purpose counters (Icestorm)",
+    [FPMC] = "Core-local general purpose counters (Firestorm)",
     [FIXED] = "Fixed counters",
     [PERF] = "Perf counters",
     [THERMAL] = "Thermal",
@@ -247,6 +350,26 @@ static char* RegisterTypeNames[MAX_UNITS] = {
     [CBOX37] = "Caching Agent box 37",
     [CBOX38] = "Caching Agent box 38",
     [CBOX39] = "Caching Agent box 39",
+    [CBOX40] = "Caching Agent box 40",
+    [CBOX41] = "Caching Agent box 41",
+    [CBOX42] = "Caching Agent box 42",
+    [CBOX43] = "Caching Agent box 43",
+    [CBOX44] = "Caching Agent box 44",
+    [CBOX45] = "Caching Agent box 45",
+    [CBOX46] = "Caching Agent box 46",
+    [CBOX47] = "Caching Agent box 47",
+    [CBOX48] = "Caching Agent box 48",
+    [CBOX49] = "Caching Agent box 49",
+    [CBOX50] = "Caching Agent box 50",
+    [CBOX51] = "Caching Agent box 51",
+    [CBOX52] = "Caching Agent box 52",
+    [CBOX53] = "Caching Agent box 53",
+    [CBOX54] = "Caching Agent box 54",
+    [CBOX55] = "Caching Agent box 55",
+    [CBOX56] = "Caching Agent box 56",
+    [CBOX57] = "Caching Agent box 57",
+    [CBOX58] = "Caching Agent box 58",
+    [CBOX59] = "Caching Agent box 59",
     [PBOX] = "Physical Layer box 0",
     [PBOX1] = "Physical Layer box 1",
     [PBOX2] = "Physical Layer box 2",
@@ -269,6 +392,7 @@ static char* RegisterTypeNames[MAX_UNITS] = {
     [QBOX0] = "QPI Link Layer 0",
     [QBOX1] = "QPI Link Layer 1",
     [QBOX2] = "QPI Link Layer 2",
+    [QBOX3] = "QPI Link Layer 3",
 #endif
     [QBOX0FIX] = "QPI Link Layer rate status 0",
     [QBOX1FIX] = "QPI Link Layer rate status 1",
@@ -314,7 +438,9 @@ static char* RegisterTypeNames[MAX_UNITS] = {
         (((type) >= 0 && (type) <= 63 ? eventset->regTypeMask1 & (1ULL<<(type)) : \
         ((type) >= 64 && (type) <= 127 ? eventset->regTypeMask2 & (1ULL<<((type)-64)) : \
         ((type) >= 128 && (type) <= 191 ? eventset->regTypeMask3 & (1ULL<<((type)-128)) : \
-        ((type) >= 192 && (type) <= 255 ? eventset->regTypeMask4 & (1ULL<<((type)-192)) : 0x0ULL)))))
+        ((type) >= 192 && (type) <= 255 ? eventset->regTypeMask4 & (1ULL<<((type)-192)) : \
+        ((type) >= 256 && (type) <= 319 ? eventset->regTypeMask5 & (1ULL<<((type)-256)) : \
+        ((type) >= 320 && (type) <= 383 ? eventset->regTypeMask6 & (1ULL<<((type)-320)) : 0x0ULL)))))))
 
 #define SETTYPE(eventset, type) \
         if ((type) >= 0 && (type) <= 63) \
@@ -333,6 +459,14 @@ static char* RegisterTypeNames[MAX_UNITS] = {
         { \
             eventset->regTypeMask4 |= (1ULL<<((type)-192)); \
         } \
+        else if ((type) >= 256 && (type) <= 319) \
+        { \
+            eventset->regTypeMask5 |= (1ULL<<((type)-256)); \
+        } \
+        else if ((type) >= 320 && (type) <= 383) \
+        { \
+            eventset->regTypeMask6 |= (1ULL<<((type)-320)); \
+        } \
         else \
         { \
             ERROR_PRINT(Cannot set out-of-bounds type %d, (type)); \
@@ -343,7 +477,7 @@ static char* RegisterTypeNames[MAX_UNITS] = {
 #define MEASURE_METRICS(eventset) ((eventset)->regTypeMask1 & (REG_TYPE_MASK(METRICS))
 
 #define MEASURE_UNCORE(eventset) \
-        (eventset->regTypeMask1 & ~(REG_TYPE_MASK(PMC)|REG_TYPE_MASK(FIXED)|REG_TYPE_MASK(THERMAL)|REG_TYPE_MASK(VOLTAGE)|REG_TYPE_MASK(PERF)|REG_TYPE_MASK(POWER)|REG_TYPE_MASK(METRICS)) || eventset->regTypeMask2 || eventset->regTypeMask3 || eventset->regTypeMask4)
+        (eventset->regTypeMask1 & ~(REG_TYPE_MASK(PMC)|REG_TYPE_MASK(FIXED)|REG_TYPE_MASK(THERMAL)|REG_TYPE_MASK(VOLTAGE)|REG_TYPE_MASK(PERF)|REG_TYPE_MASK(POWER)|REG_TYPE_MASK(METRICS)) || eventset->regTypeMask2 || eventset->regTypeMask3 || eventset->regTypeMask4 || eventset->regTypeMask5 || eventset->regTypeMask6 )
 
 
 typedef struct {
