@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of topology backend using procfs/sysfs
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -31,7 +31,7 @@
 #define TOPOLOGY_MISC_H
 
 int num_nvidia_devices();
-int fill_nvidia_device(int id, GpuDevice* device);
+int fill_nvidia_device(int id, CudaDevice* device);
 
 
 #endif /* TOPOLOGY_MISC_H */
