@@ -5,14 +5,14 @@
  *
  *      Description:  Module implementing Intel RAPL interface
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Authors:  Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -67,9 +67,10 @@ power_init(int cpuId)
     {
         return 0;
     }
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, Init power);
     if (!lock_check())
     {
-        ERROR_PLAIN_PRINT(Access to performance monitoring registers locked);
+        ERROR_PRINT(Access to performance monitoring registers locked);
         return -ENOLCK;
     }
     init_configuration();
@@ -86,6 +87,7 @@ power_init(int cpuId)
     power_info.uncoreMinFreq = 0;
     power_info.uncoreMaxFreq = 0;
     power_info.perfBias = 0;
+    power_info.statusRegWidth = 32;
     if (config->daemonMode == ACCESSMODE_PERF)
     {
         ERROR_PRINT(RAPL in access mode 'perf_event' only available with perfmon);
@@ -138,6 +140,7 @@ power_init(int cpuId)
                 case SKYLAKEX:
                 case ICELAKEX1:
                 case ICELAKEX2:
+                case SAPPHIRERAPIDS:
                     core_limits = 1;
                     power_info.hasRAPL = 1;
                     numDomains = NUM_POWER_DOMAINS;
@@ -157,7 +160,6 @@ power_init(int cpuId)
             }
             break;
         case ZEN_FAMILY:
-        case ZEN3_FAMILY:
             if (cpuid_info.model == ZEN_RYZEN ||
                 cpuid_info.model == ZENPLUS_RYZEN ||
                 cpuid_info.model == ZENPLUS_RYZEN2 ||
@@ -166,7 +168,8 @@ power_init(int cpuId)
                 cpuid_info.model == ZEN2_RYZEN3 ||
                 cpuid_info.model == ZEN3_RYZEN ||
                 cpuid_info.model == ZEN3_RYZEN2 ||
-                cpuid_info.model == ZEN3_RYZEN3)
+                cpuid_info.model == ZEN3_RYZEN3 ||
+                cpuid_info.model == ZEN3_EPYC_TRENTO)
             {
                 cpuid_info.turbo = 0;
                 power_info.hasRAPL = 1;
@@ -186,6 +189,51 @@ power_init(int cpuId)
                 }
             }
             break;
+        case ZEN3_FAMILY:
+            switch (cpuid_info.model)
+            {
+                case ZEN3_RYZEN:
+                case ZEN3_RYZEN2:
+                case ZEN3_RYZEN3:
+                    cpuid_info.turbo = 0;
+                    power_info.hasRAPL = 1;
+                    numDomains = 2;
+                    unit_reg = MSR_AMD17_RAPL_POWER_UNIT;
+                    power_names[0] = "CORE";
+                    power_names[1] = "PKG";
+                    power_regs[0] = MSR_AMD17_RAPL_CORE_STATUS;
+                    power_regs[1] = MSR_AMD17_RAPL_PKG_STATUS;
+
+                    for (i = 0; i< NUM_POWER_DOMAINS; i++)
+                    {
+                        limit_regs[i] = 0x0;
+                        policy_regs[i] = 0x0;
+                        perf_regs[i] = 0x0;
+                        info_regs[i] = 0x0;
+                    }
+                    break;
+                case ZEN4_RYZEN:
+                case ZEN4_EPYC:
+                    cpuid_info.turbo = 0;
+                    power_info.hasRAPL = 1;
+                    power_info.statusRegWidth = 64;
+                    numDomains = 2;
+                    unit_reg = MSR_AMD17_RAPL_POWER_UNIT;
+                    power_names[0] = "CORE";
+                    power_names[1] = "L3";
+                    power_regs[0] = MSR_AMD17_RAPL_CORE_STATUS;
+                    power_regs[1] = MSR_AMD19_RAPL_L3_STATUS;
+
+                    for (i = 0; i< NUM_POWER_DOMAINS; i++)
+                    {
+                        limit_regs[i] = 0x0;
+                        policy_regs[i] = 0x0;
+                        perf_regs[i] = 0x0;
+                        info_regs[i] = 0x0;
+                    }
+                    break;
+            }
+            break;
     }
 
     perfmon_init_maps();
@@ -195,7 +243,7 @@ power_init(int cpuId)
         err = HPMaddThread(cpuId);
         if (err != 0)
         {
-            ERROR_PLAIN_PRINT(Cannot get access to RAPL counters)
+            ERROR_PRINT(Cannot get access to RAPL counters)
             return err;
         }
     }
@@ -232,15 +280,14 @@ power_init(int cpuId)
             err = HPMread(cpuId, MSR_DEV, MSR_TURBO_RATIO_LIMIT, &flags);
             if (err)
             {
-                fprintf(stderr,"Cannot gather values from MSR_TURBO_RATIO_LIMIT\n");
+                ERROR_PRINT(Cannot gather values from %s, "MSR_TURBO_RATIO_LIMIT");
             }
             else
             {
                 if (!core_limits)
                 {
-                    unsigned long flag_vals[4];
+                    uint64_t flag_vals[4];
                     int flag_idx = 0;
-                    int reg_idx = 1;
                     int valid_idx = 0;
                     flag_vals[0] = flags;
                     if (power_info.turbo.numSteps > 8)
@@ -248,6 +295,7 @@ power_init(int cpuId)
                         err = HPMread(cpuId, MSR_DEV, MSR_TURBO_RATIO_LIMIT1, &flag_vals[1]);
                         if (err)
                         {
+                            ERROR_PRINT(Cannot read core limits from %s, "MSR_TURBO_RATIO_LIMIT1");
                             flag_vals[1] = 0;
                         }
                     }
@@ -256,6 +304,7 @@ power_init(int cpuId)
                         err = HPMread(cpuId, MSR_DEV, MSR_TURBO_RATIO_LIMIT2, &flag_vals[2]);
                         if (err)
                         {
+                            ERROR_PRINT(Cannot read core limits from %s, "MSR_TURBO_RATIO_LIMIT2");
                             flag_vals[2] = 0;
                         }
                     }
@@ -264,6 +313,7 @@ power_init(int cpuId)
                         err = HPMread(cpuId, MSR_DEV, MSR_TURBO_RATIO_LIMIT3, &flag_vals[3]);
                         if (err)
                         {
+                            ERROR_PRINT(Cannot read core limits from %s, "MSR_TURBO_RATIO_LIMIT3");
                             flag_vals[3] = 0;
                         }
                     }
@@ -273,7 +323,6 @@ power_init(int cpuId)
                         if (i % 8 == 0)
                         {
                             flag_idx++;
-                            reg_idx = 0;
                         }
                         power_info.turbo.steps[i] = busSpeed * (double) field64(flag_vals[flag_idx],(i%8)*8, 8);
                         if (power_info.turbo.steps[i] > 0)
@@ -289,7 +338,7 @@ power_init(int cpuId)
                     err = HPMread(cpuId, MSR_DEV, MSR_TURBO_RATIO_LIMIT_CORES, &flags_cores);
                     if (err)
                     {
-                        ERROR_PLAIN_PRINT(Cannot read MSR TURBO_RATIO_LIMIT_CORES);
+                        ERROR_PRINT(Cannot read core limits from %s, "MSR_TURBO_RATIO_LIMIT_CORES");
                         flags_cores = 0;
                     }
                     for (int i = 0; i < 8; i++)
@@ -310,7 +359,7 @@ power_init(int cpuId)
         }
         else
         {
-            fprintf(stderr,"Cannot gather values from MSR_PLATFORM_INFO\n");
+            ERROR_PRINT(Cannot gather values from %s, "MSR_PLATFORM_INFO");
         }
     }
 
@@ -341,7 +390,7 @@ power_init(int cpuId)
                 power_info.domains[i].maxPower = 0.0;
                 power_info.domains[i].maxTimeWindow = 0.0;
             }
-            if ((cpuid_info.model == HASWELL_EP) ||
+            if (cpuid_info.family == P6_FAMILY && ((cpuid_info.model == HASWELL_EP) ||
                 (cpuid_info.model == HASWELL_M1) ||
                 (cpuid_info.model == HASWELL_M2) ||
                 (cpuid_info.model == BROADWELL_D) ||
@@ -349,8 +398,9 @@ power_init(int cpuId)
                 (cpuid_info.model == SKYLAKEX) ||
                 (cpuid_info.model == ICELAKEX1) ||
                 (cpuid_info.model == ICELAKEX2) ||
+                (cpuid_info.model == SAPPHIRERAPIDS) ||
                 (cpuid_info.model == XEON_PHI_KNL) ||
-                (cpuid_info.model == XEON_PHI_KML))
+                (cpuid_info.model == XEON_PHI_KML)))
             {
                 power_info.domains[DRAM].energyUnit = 15.3E-6;
             }
@@ -432,7 +482,7 @@ power_init(int cpuId)
         }
         else
         {
-            fprintf(stderr,"Cannot gather values from unit register 0x%X, deactivating RAPL support\n", unit_reg);
+            DEBUG_PRINT(DEBUGLEV_INFO, Cannot gather values from unit register 0x%X. deactivating RAPL support, unit_reg);
             power_info.hasRAPL =  0;
         }
 
@@ -450,6 +500,17 @@ power_init(int cpuId)
                 power_info.perfBias = flags & 0xF;
             }
         }
+
+        if (cpuid_info.family == ZEN3_FAMILY && (cpuid_info.model == ZEN4_RYZEN || cpuid_info.model == ZEN4_EPYC))
+        {
+            err = HPMread(cpuId, MSR_DEV, MSR_AMD19_RAPL_L3_UNIT, &flags);
+            if (err == 0)
+            {
+                DEBUG_PRINT(DEBUGLEV_DETAIL, Reading energy unit for Zen4 L3 RAPL domain);
+                power_info.domains[1].energyUnit = 1.0 / (1 << ((flags >> 8) & 0x1F));
+            }
+        }
+        power_info.numDomains = numDomains;
         power_initialized = 1;
         return power_info.hasRAPL;
     }
@@ -490,8 +551,7 @@ power_limitSet(int cpuId, PowerType domain, double power, double time, int doCla
     {
         return -EINVAL;
     }
-    fprintf(stderr, "Not implemented\n");
-    return 0;
+
 
     uint32_t X = (log(time) - log(power_info.timeUnit))/log(2);
     uint32_t powerField = (uint32_t)(power/(power_info.domains[domain].energyUnit));
@@ -506,7 +566,7 @@ power_limitSet(int cpuId, PowerType domain, double power, double time, int doCla
         err = HPMwrite(cpuId, MSR_DEV, limit_regs[domain], flags);
         if (err)
         {
-            fprintf(stderr, "Failed to set power limit for domain %s on CPU %d\n",power_names[domain], cpuId);
+            ERROR_PRINT(Failed to set power limit for domain %s on CPU %d,power_names[domain], cpuId);
             return -EFAULT;
         }
     }
@@ -530,7 +590,7 @@ power_limitGet(int cpuId, PowerType domain, double* power, double* time)
         err = HPMread(cpuId, MSR_DEV, limit_regs[domain], &flags);
         if (err)
         {
-            fprintf(stderr, "Failed to set power limit for domain %s on CPU %d\n",power_names[domain], cpuId);
+            ERROR_PRINT(Failed to set power limit for domain %s on CPU %d,power_names[domain], cpuId);
             return -EFAULT;
         }
         *power = ((double)extractBitField(flags, 15, 0)) * power_info.domains[domain].energyUnit;
