@@ -5,14 +5,14 @@
  *
  *      Description:  Interface to the hwloc based topology backend
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Authors:  Thomas Gruber (tr), thomas.roehl@googlemail.com
  *
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -63,54 +63,61 @@ int parse_cpuinfo(uint32_t* count, uint32_t* family, uint32_t* variant, uint32_t
     uint32_t c = 0;
     int (*ownatoi)(const char*);
     ownatoi = &atoi;
+    struct tagbstring familyString = bsStatic("CPU architecture");
+    struct tagbstring variantString = bsStatic("CPU variant");
+    struct tagbstring steppingString = bsStatic("CPU revision");
+    struct tagbstring partString = bsStatic("CPU part");
+    struct tagbstring vendString = bsStatic("CPU implementer");
+    struct tagbstring procString = bsStatic("processor");
 
     if (NULL != (fp = fopen ("/proc/cpuinfo", "r")))
     {
-        const_bstring familyString = bformat("CPU architecture");
-        const_bstring variantString = bformat("CPU variant");
-        const_bstring steppingString = bformat("CPU revision");
-        const_bstring partString = bformat("CPU part");
-        const_bstring vendString = bformat("CPU implementer");
-        const_bstring procString = bformat("processor");
         bstring src = bread ((bNread) fread, fp);
         struct bstrList* tokens = bsplit(src,(char) '\n');
         bdestroy(src);
         fclose(fp);
         for (i=0;i<tokens->qty;i++)
         {
-            if ((f == 0) && (binstr(tokens->entry[i],0,procString) != BSTR_ERR))
+            if ((binstr(tokens->entry[i],0,&procString) != BSTR_ERR))
             {
-                c++;
+                struct bstrList* subtokens = bsplit(tokens->entry[i],(char) ':');
+                bltrimws(subtokens->entry[1]);
+                uint32_t tmp = ownatoi(bdata(subtokens->entry[1]));
+                if (tmp > c)
+                {
+                    c = tmp;
+                }
+                bstrListDestroy(subtokens);
             }
-            else if ((f == 0) && (binstr(tokens->entry[i],0,familyString) != BSTR_ERR))
+            else if ((f == 0) && (binstr(tokens->entry[i],0,&familyString) != BSTR_ERR))
             {
                 struct bstrList* subtokens = bsplit(tokens->entry[i],(char) ':');
                 bltrimws(subtokens->entry[1]);
                 f = ownatoi(bdata(subtokens->entry[1]));
                 bstrListDestroy(subtokens);
             }
-            else if ((s == 0) && (binstr(tokens->entry[i],0,steppingString) != BSTR_ERR))
+            else if ((s == 0) && (binstr(tokens->entry[i],0,&steppingString) != BSTR_ERR))
             {
                 struct bstrList* subtokens = bsplit(tokens->entry[i],(char) ':');
                 bltrimws(subtokens->entry[1]);
                 s = ownatoi(bdata(subtokens->entry[1]));
                 bstrListDestroy(subtokens);
             }
-            else if ((v == 0) && (binstr(tokens->entry[i],0,variantString) != BSTR_ERR))
+            else if ((v == 0) && (binstr(tokens->entry[i],0,&variantString) != BSTR_ERR))
             {
                 struct bstrList* subtokens = bsplit(tokens->entry[i],(char) ':');
                 bltrimws(subtokens->entry[1]);
                 v = strtol(bdata(subtokens->entry[1]), NULL, 0);
                 bstrListDestroy(subtokens);
             }
-            else if ((p == 0) && (binstr(tokens->entry[i],0,partString) != BSTR_ERR))
+            else if ((p == 0) && (binstr(tokens->entry[i],0,&partString) != BSTR_ERR))
             {
                 struct bstrList* subtokens = bsplit(tokens->entry[i],(char) ':');
                 bltrimws(subtokens->entry[1]);
                 p = strtol(bdata(subtokens->entry[1]), NULL, 0);
                 bstrListDestroy(subtokens);
             }
-            else if ((p == 0) && (binstr(tokens->entry[i],0,vendString) != BSTR_ERR))
+            else if ((vend == 0) && (binstr(tokens->entry[i],0,&vendString) != BSTR_ERR))
             {
                 struct bstrList* subtokens = bsplit(tokens->entry[i],(char) ':');
                 bltrimws(subtokens->entry[1]);
@@ -119,9 +126,6 @@ int parse_cpuinfo(uint32_t* count, uint32_t* family, uint32_t* variant, uint32_t
             }
         }
         bstrListDestroy(tokens);
-        /*bdestroy(familyString);
-        bdestroy(variantString);
-        bdestroy(steppingString);*/
     }
     else
     {
@@ -132,7 +136,7 @@ int parse_cpuinfo(uint32_t* count, uint32_t* family, uint32_t* variant, uint32_t
     *stepping = s;
     *part = p;
     *vendor = vend;
-    *count = c;
+    *count = c + 1;
     return 0;
 }
 
@@ -284,25 +288,16 @@ hwloc_init_cpuInfo(cpu_set_t cpuSet)
         cpuid_info.stepping = atoi(info);
     snprintf(cpuid_info.architecture, 19, "x86_64");
 #endif
-#ifdef __ARM_ARCH_7A__
-    if ((info = LIKWID_HWLOC_NAME(obj_get_info_by_name)(obj, "CPUArchitecture")))
-       cpuid_info.family = atoi(info);
-    if ((info = LIKWID_HWLOC_NAME(obj_get_info_by_name)(obj, "CPURevision")))
-        cpuid_info.model = atoi(info);
-    if (cpuid_info.family == 0 || cpuid_info.model == 0)
-    {
-        uint32_t part = 0;
-        parse_cpuinfo(&count, &cpuid_info.family, &cpuid_info.model, &cpuid_info.stepping, &cpuid_info.part, &cpuid_info.vendor);
-        parse_cpuname(cpuid_info.osname);
-    }
-    snprintf(cpuid_info.architecture, 19, "armv7");
-#endif
 #if defined(__ARM_ARCH_7A__) || defined(__ARM_ARCH_8A)
-    uint32_t part = 0;
     parse_cpuinfo(&count, &cpuid_info.family, &cpuid_info.model, &cpuid_info.stepping, &cpuid_info.part, &cpuid_info.vendor);
     parse_cpuname(cpuid_info.osname);
+#ifdef __ARM_ARCH_7A__
+    snprintf(cpuid_info.architecture, 19, "armv7");
+#endif
+#ifdef __ARM_ARCH_8A
     snprintf(cpuid_info.architecture, 19, "armv8");
 #endif
+#endif
 
 #ifndef _ARCH_PPC
     if ((info = LIKWID_HWLOC_NAME(obj_get_info_by_name)(obj, "CPUModel")))
@@ -344,32 +339,23 @@ hwloc_init_cpuInfo(cpu_set_t cpuSet)
 
     cpuid_topology.numHWThreads = LIKWID_HWLOC_NAME(get_nbobjs_by_type)(hwloc_topology, HWLOC_OBJ_PU);
 #if defined(__ARM_ARCH_7A__) || defined(__ARM_ARCH_8A)
-    if (cpuid_info.vendor == FUJITSU_ARM && cpuid_info.part == FUJITSU_A64FX)
-    {
-        int max_id = 0;
-        for (int i = 0; i < LIKWID_HWLOC_NAME(get_nbobjs_by_type)(hwloc_topology, HWLOC_OBJ_PU); i++)
-        {
-            obj = LIKWID_HWLOC_NAME(get_obj_by_type)(hwloc_topology, HWLOC_OBJ_PU, i);
-            if (obj->os_index > max_id)
-            {
-                max_id = obj->os_index;
-            }
-        }
-        if (max_id + 1 > count)
-        {
-            count = max_id + 1;
-        }
-    }
     if (count > cpuid_topology.numHWThreads)
     {
         cpuid_topology.numHWThreads = count;
     }
 #endif
-    count = likwid_sysfs_list_len("/sys/devices/system/cpu/online");
-    if (count > cpuid_topology.numHWThreads)
-        cpuid_topology.numHWThreads = count;
-    if (cpuid_topology.activeHWThreads > cpuid_topology.numHWThreads)
-        cpuid_topology.numHWThreads = cpuid_topology.activeHWThreads;
+    if (!getenv("HWLOC_FSROOT"))
+    {
+        count = likwid_sysfs_list_len("/sys/devices/system/cpu/online");
+        if (count > cpuid_topology.numHWThreads)
+        {
+            cpuid_topology.numHWThreads = count;
+        }
+        if (cpuid_topology.activeHWThreads > cpuid_topology.numHWThreads)
+        {
+            cpuid_topology.numHWThreads = cpuid_topology.activeHWThreads;
+        }
+    }
     DEBUG_PRINT(DEBUGLEV_DEVELOP, HWLOC CpuInfo Family %d Model %d Stepping %d Vendor 0x%X Part 0x%X isIntel %d numHWThreads %d activeHWThreads %d,
                             cpuid_info.family,
                             cpuid_info.model,
@@ -590,6 +576,7 @@ hwloc_init_nodeTopology(cpu_set_t cpuSet)
 
     int socket_nums[MAX_NUM_NODES];
     int num_sockets = 0;
+    int has_zero_id = 0;
     for (uint32_t i=0; i< cpuid_topology.numHWThreads; i++)
     {
         int found = 0;
@@ -606,14 +593,22 @@ hwloc_init_nodeTopology(cpu_set_t cpuSet)
             socket_nums[num_sockets] = hwThreadPool[i].packageId;
             num_sockets++;
         }
-    }
-    for (uint32_t i=0; i< cpuid_topology.numHWThreads; i++)
-    {
-        for (uint32_t j=0; j < num_sockets; j++)
+        if (hwThreadPool[i].packageId == 0)
         {
-            if (hwThreadPool[i].packageId == socket_nums[j])
+            has_zero_id = 1;
+        }
+    }
+    if (!has_zero_id)
+    {
+        for (uint32_t i=0; i< cpuid_topology.numHWThreads; i++)
+        {
+            HWThread* t = &hwThreadPool[i];
+            for (uint32_t j=0; j < num_sockets; j++)
             {
-                hwThreadPool[i].packageId = j;
+                if (hwThreadPool[i].packageId == socket_nums[j])
+                {
+                    hwThreadPool[i].packageId = j;
+                }
             }
         }
     }
