@@ -5,14 +5,14 @@
  *
  *      Description:  Interface to the procfs/sysfs based topology backend
  *
- *      Version:   5.2.2
- *      Released:  26.07.2022
+ *      Version:   5.3
+ *      Released:  10.11.2023
  *
  *      Authors:  Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2022 NHR@FAU, University Erlangen-Nuremberg
+ *      Copyright (C) 2023 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -213,12 +213,6 @@ proc_init_cpuInfo(cpu_set_t cpuSet)
     const_bstring vendorString = bformat("CPU implementer\t:");
     const_bstring familyString = bformat("CPU architecture");
 #endif
-    cpuid_info.osname = malloc(MAX_MODEL_STRING_LENGTH * sizeof(char));
-    if (!cpuid_info.osname)
-    {
-        return;
-    }
-    cpuid_info.osname[0] = '\0';
 
     const_bstring countString = bformat("processor\t:");
 
@@ -232,7 +226,8 @@ proc_init_cpuInfo(cpu_set_t cpuSet)
 #endif
     cpuid_info.stepping = 0;
     cpuid_topology.numHWThreads = 0;
-    
+    cpuid_info.osname = malloc(MAX_MODEL_STRING_LENGTH * sizeof(char));
+    cpuid_info.osname[0] = '\0';
 
     if (NULL != (fp = fopen ("/proc/cpuinfo", "r")))
     {
@@ -373,7 +368,7 @@ proc_init_cpuFeatures(void)
         if (bstrncmp(cpulines->entry[i], &featString, 8) == BSTR_OK)
 #endif
 #ifdef _ARCH_PPC
-    if (ret != 1)
+	if (ret != 1)
 #endif
         {
             bdestroy(flagline);
@@ -742,6 +737,65 @@ proc_init_nodeTopology(cpu_set_t cpuSet)
             helper[hidx++] = pid;
         }
     }
+    int tmp_numSockets = hidx;
+    hidx = 0;
+    for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    {
+        int pid = hwThreadPool[i].dieId;
+        int found = 0;
+        for (int j = 0; j < hidx; j++)
+        {
+            if (pid == helper[j])
+            {
+                found = 1;
+                break;
+            }
+        }
+        if (!found)
+        {
+            helper[hidx++] = pid;
+        }
+    }
+    int tmp_numDies = hidx;
+    if (tmp_numSockets == 1 && tmp_numDies == 1)
+    {
+        for (uint32_t i=0;i<cpuid_topology.numHWThreads;i++)
+        {
+            cpudir = bformat("/sys/devices/system/cpu/cpu%d/topology",i);
+            file = bformat("%s/cluster_id", bdata(cpudir));
+            if (NULL != (fp = fopen (bdata(file), "r")))
+            {
+                bstring src = bread ((bNread) fread, fp);
+                int packageId = ownatoi(bdata(src));
+                hwThreadPool[i].packageId = packageId;
+                if (packageId > last_socket)
+                {
+                    num_sockets++;
+                    last_socket = packageId;
+                }
+                fclose(fp);
+            }
+            bdestroy(file);
+        }
+    }
+    hidx = 0;
+    for (int i = 0; i < cpuid_topology.numHWThreads; i++)
+    {
+        int pid = hwThreadPool[i].packageId;
+        int found = 0;
+        for (int j = 0; j < hidx; j++)
+        {
+            if (pid == helper[j])
+            {
+                found = 1;
+                break;
+            }
+        }
+        if (!found)
+        {
+            helper[hidx++] = pid;
+        }
+    }
     cpuid_topology.numSockets = hidx;
     /* Traverse all sockets to get maximal thread count per socket.
      * This should fix the code for architectures with "empty" sockets.
